TrapFrame

Struct TrapFrame 

#[repr(C, packed(1))]
pub struct TrapFrame {
Show 21 fields pub rbx: u64, pub r12: u64, pub r13: u64, pub r14: u64, pub r15: u64, pub rbp: u64, pub r11: u64, pub r10: u64, pub r9: u64, pub r8: u64, pub rsi: u64, pub rdi: u64, pub rdx: u64, pub rcx: u64, pub rax: u64, pub err_code: u64, pub rip: u64, pub cs: u64, pub rflags: u64, pub rsp: u64, pub ss: u64,
}
TrapFrame is saved and restored by the interrupt handler assembly code upon interrupt entry and exit.

The complete picture (in pushing sequence, addr from high to low)

Fields

rbx: u64r12: u64r13: u64r14: u64r15: u64rbp: u64r11: u64r10: u64r9: u64r8: u64rsi: u64rdi: u64rdx: u64rcx: u64rax: u64err_code: u64

for some exceptions, the CPU automatically pushes an error code (see docs/interrupt.txt) to the stack. For those who don’t have error code, we manually push a dummy value (0)

rip: u64cs: u64rflags: u64rsp: u64ss: u64

Implementations

Source

impl TrapFrame

pub fn from_user(&self) -> bool

get rpl from auto-pushed cs register